summaryrefslogtreecommitdiff
path: root/src/mint/taler-mint-httpd_parsing.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2015-07-05 13:48:35 +0200
committerChristian Grothoff <christian@grothoff.org>2015-07-05 13:48:35 +0200
commitac8420a66140aa850b1573a3503ed3a7f3cc974c (patch)
tree9a88a19c29a27f1a47da1487c04871a8f667ca61 /src/mint/taler-mint-httpd_parsing.h
parenta104914e4d209d9c2d94a8f4e943dd29e739158a (diff)
downloadexchange-ac8420a66140aa850b1573a3503ed3a7f3cc974c.tar.gz
exchange-ac8420a66140aa850b1573a3503ed3a7f3cc974c.tar.bz2
exchange-ac8420a66140aa850b1573a3503ed3a7f3cc974c.zip
add cov for mint build
Diffstat (limited to 'src/mint/taler-mint-httpd_parsing.h')
-rw-r--r--src/mint/taler-mint-httpd_parsing.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/mint/taler-mint-httpd_parsing.h b/src/mint/taler-mint-httpd_parsing.h
index ea4eddb22..44e74d27c 100644
--- a/src/mint/taler-mint-httpd_parsing.h
+++ b/src/mint/taler-mint-httpd_parsing.h
@@ -252,13 +252,17 @@ TMH_PARSE_release_data (struct TMH_PARSE_FieldSpecification *spec);
*/
#define TMH_PARSE_MEMBER_VARIABLE(field) { field, NULL, 0, 0, TMH_PARSE_JNC_RET_DATA_VAR, 0 }
+
/**
* Generate line in parser specification for JSON array value.
*
* @param field name of the field
* @param ptraddr address of pointer to initialize (a `void **`)
*/
-#define TMH_PARSE_MEMBER_ARRAY(field,ptraddr) { field, ptraddr, 0, 0, TMH_PARSE_JNC_RET_TYPED_JSON, JSON_ARRAY }
+struct TMH_PARSE_FieldSpecification
+TMH_PARSE_member_array (const char *field,
+ json_t **jsonp);
/**
@@ -252,13 +252,17 @@ TMH_PARSE_release_data (struct TMH_PARSE_FieldSpecification *spec);
*
* @param field name of the field
- * @param ptraddr address of pointer to initialize (a `void **`)
+ * @param ptraddr address of JSON pointer to initialize
+ * @return corresponding field spec
*/